// Copyright(c) 1998, 1999, Hagiwara Youichi
// All rights reserved.

// Reference
// [Stroustrup, 1997] Bjarne Stroustrup: The C++ Programming Language (Third Edition). Addison-Wesley. Reading, Mass. 1997. ISBN 0-201-88954-4.

#include <fstream>	//[Stroustrup, 1997] Section 16.1.2, Page 433
#include <iostream>	//[Stroustrup, 1997] Section 16.1.2, Page 433
#include <string>	//[Stroustrup, 1997] Section 16.1.2, Page 432

using namespace std;	//[Stroustrup, 1997] Section 3.3, Page 47

int main()
{
	cout << "------------------------" << endl
			<< "Base HTML File Generator" << endl
			<< "------------------------" << endl
			<< endl;

	unsigned short doctype = 4;
	cout << "HTML type? ([1]2.0 [2]3.2 [3]4.0 Strict [4]4.0 Transitional [5]4.0 Frameset) " << flush;
	cin >> doctype;

	unsigned short charset = 3;
	cout << "Charactor set? ([1]JIS [2]Shift-JIS [3]EUC) " << flush;
	cin >> charset;

	string title = "title";	//[Stroustrup, 1997] Section 3.5, Page 48
	cout << "Title? " << flush;
	cin >> ws;	// eat \n at to set "charset"
	getline(cin, title);	//[Stroustrup, 1997] Section 3.6, Page 51

	string address = "address@geocities.co.jp";	//[Stroustrup, 1997] Section 3.5, Page 48
	cout << "E-mail address? " << flush;
	getline(cin, address);	//[Stroustrup, 1997] Section 3.6, Page 51

	bool geo = true;
	cout << "GeoCities? ([0]no [1]yes) " << flush;	// for GeoCities user
	cin >> geo;

	string filename = "filename.html";	//[Stroustrup, 1997] Section 3.5, Page 48
	cout << "File name? " << flush;
	cin >> ws;	// eat \n at to set "geo"
	getline(cin, filename);	//[Stroustrup, 1997] Section 3.6, Page 51

	ofstream result(filename.c_str());	//[Stroustrup, 1997] Section 3.8.3, Page 61
	if (!result) {
		cerr << "Error! I failed to open \"" << filename <<"\"." << flush;
		return 1;
	}

	switch (doctype) {
		case 1 :
			result << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">" << endl;
			break;
		case 2 :
			result << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 3.2 Final//EN\">" << endl;
			break;
		case 3 :
			result << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\"" << endl
					<< "\t\"http://www.w3.org/TR/REC-html40/strict.dtd\">" << endl;
			break;
		case 4 :
			result << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\"" << endl
					<< "\t\"http://www.w3.org/TR/REC-html40/loose.dtd\">" << endl;
			break;
		case 5 :
			result << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Frameset//EN\"" << endl
					<< "\t\"http://www.w3.org/TR/REC-html40/frameset.dtd\">" << endl;
			break;
	}

	switch (doctype) {
		case 1 : case 2 :
			result << "<HTML>" << endl;
			break;
		case 3 : case 4 : case 5 :
			result << "<HTML lang=\"ja\">" << endl;
			break;
	}

	result << "\t<HEAD>" << endl;

	switch (doctype) {
		case 1 :
			result << "\t\t<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; " << flush;
			break;
		case 2 : case 3 : case 4 : case 5 :
			result << "\t\t<META http-equiv=\"Content-Type\" content=\"text/html; " << flush;
			break;
	}
	switch (charset) {
		case 1 :
			result << "charset=ISO-2022-JP\">" << endl;
			break;
		case 2 :
			result << "charset=SHIFT_JIS\">" << endl;
			break;
		case 3 :
			result << "charset=EUC-JP\">" << endl;
			break;
	}

	switch (doctype) {
		case 1 : case 2 :
			result << "\t\t<TITLE>" << title << "</TITLE>" << endl;
			break;
		case 3 : case 4 : case 5 :
			result << "\t\t<TITLE lang=\"ja\">" << title << "</TITLE>" << endl;
			break;
	}

	switch (doctype) {
		case 1 :
			result << "\t\t<LINK REV=\"Made\" HREF=\"mailto:" << address << "\">" << endl;
			break;
		case 2 : case 3 : case 4 : case 5 :
			result << "\t\t<LINK rev=\"Made\" href=\"mailto:" << address << "\">" << endl;
			break;
	}

	result << "\t</HEAD>" << endl;

	switch (doctype) {
		case 1 : case 2 : case 3 : case 4 :
			result << "\t<BODY>" << endl;
			if (geo == true)
				result << "\t\t<!--#geoguide-->" << endl;
			result << "\t\t" << endl;
			result << "\t</BODY>" << endl;
			break;
		case 5 :
			result << "\t<FRAMESET>" << endl
					<< "\t\t<FRAME name=\"\" src=\"\">" << endl
					<< "\t\t<NOFRAMES><BODY>" << endl;
			if (geo == true)
				result << "\t\t\t<!--#geoguide-->" << endl;
			result << "\t\t\t" << endl
					<< "\t\t</BODY></NOFRAMES>" << endl
					<< "\t</FRAMESET>" << endl;
			break;
	}

	result << "</HTML>" << flush;

	result.close();

	cout << endl<< "Finished!" << flush;

	return 0;
}